@@ -4,7 +4,7 @@ import subprocess
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_this, run_cdo, tidy_command
-from nctoolkit.session import nc_safe, session_info
+from nctoolkit.session import nc_safe, session_info, append_safe, remove_safe
 from nctoolkit.show import nc_variables
 from nctoolkit.temp_file import temp_file
 
@@ -55,7 +55,7 @@ def operation(self, method="mul", ff=None, var=None):
     # make sure the ff file is not removed from safe list in subsequent
     # actions prior to running
     if (ff is not None) and (session_info["lazy"]):
-        nc_safe.append(ff)
+        append_safe(ff)
         self._safe.append(ff)
 
     if len(self.history) == len(self._hold_history):
@@ -113,10 +113,10 @@ def operation(self, method="mul", ff=None, var=None):
             self.history.append(cc.replace("  ", " "))
 
         self.current = new_files
+
+        for ff in new_files:
+            remove_safe(ff)
         self._hold_history = copy.deepcopy(self.history)
-        for rr in self._safe:
-            nc_safe.remove(ff)
-        self._safe = []
         cleanup()
 
     # update history if lazy
@@ -126,6 +126,8 @@ def operation(self, method="mul", ff=None, var=None):
         else:
             self.history.append(cdo_command)
 
+    # remove anything from self._safe if it was ever set up
+
     cleanup()
 
 
@@ -141,6 +143,24 @@ def multiply(self, x=None, var=None):
         in it, unless var is supplied. The grids must be the same.
     var: str
         A variable in the x to multiply the dataset by
+
+    Examples
+    ------------
+
+    If you wanted to multiply variables in a dataset by 10, you would do the following:
+
+    >>> data.multiply(10)
+
+    To multiply the values in a dataset by the values of variables in dataset data2, you would do the following:
+
+    >>> data1.multiply(data2)
+
+    Grids in the datasets must match. Multiplication will occur in matching timesteps in data1 and data2. If there is only 1 timestep in data2, then
+    the data from that timestep in data2 will multiply the data in all timesteps in data1.
+
+    Multiplying a dataset by the data from another NetCDF file will work in the same way:
+
+    >>> data1.multiply("example.nc")
     """
 
     # 1: int, float multiplication
@@ -152,7 +172,10 @@ def multiply(self, x=None, var=None):
     # get the netcdf file(s)
     if "api.DataSet" in str(type(x)):
         x.run()
-        ff = x.current
+        if len(x) == 1:
+            ff = x.current[0]
+        else:
+            raise TypeError("This can only work with single variable datasets")
     else:
         ff = x
 
@@ -174,6 +197,24 @@ def subtract(self, x=None, var=None):
         unless var is provided. The grids must be the same.
     var: str
         A variable in the x to use for the operation
+
+    Examples
+    ------------
+
+    If you wanted to subtract 10 from all variables in a dataset, you would do the following:
+
+    >>> data.subtract(10)
+
+    To substract the values in a dataset data2 from those in a dataset data1, you would do the following:
+
+    >>> data1.subtract(data2)
+
+    Grids in the datasets must match. Division will occur in matching timesteps in data1 and data2 if there are matching timesteps. If there is only 1 timestep in data2, then
+    the data from that timestep in data2 will be subtracted from the data in all timesteps in data1.
+
+    Subtracting of the data from another NetCDF file will work in the same way:
+
+    >>> data1.subtract("example.nc")
     """
 
     # 1: int, float subtraction
@@ -185,7 +226,10 @@ def subtract(self, x=None, var=None):
     # get the netcdf file(s)
     if "api.DataSet" in str(type(x)):
         x.run()
-        ff = x.current
+        if len(x) == 1:
+            ff = x.current[0]
+        else:
+            raise TypeError("This can only work with single variable datasets")
     else:
         ff = x
 
@@ -207,8 +251,29 @@ def add(self, x=None, var=None):
         unless var is provided. The grids must be the same.
     var: str
         A variable in the x to use for the operation
+
+    Examples
+    ------------
+
+    If you wanted to add 10 to all variables in a dataset, you would do the following:
+
+    >>> data.add(10)
+
+    To add the values in a dataset data2 from a dataset data1, you would do the following:
+
+    >>> data1.add(data2)
+
+    Grids in the datasets must match. Addition will occur in matching timesteps in data1 and data2. If there is only 1 timestep in data2, then
+    the data from that timestep will be added to the data in all data1 time steps.
+
+    Adding the data from another NetCDF file will work in the same way:
+
+    >>> data1.add("example.nc")
+
+
     """
 
+
     # 1: int, float addition
     if isinstance(x, (int, float)):
         arithall(self, stat="addc", x=x)
@@ -218,7 +283,10 @@ def add(self, x=None, var=None):
     # get the netcdf file(s)
     if "api.DataSet" in str(type(x)):
         x.run()
-        ff = x.current
+        if len(x) == 1:
+            ff = x.current[0]
+        else:
+            raise TypeError("This can only work with single variable datasets")
     else:
         ff = x
 
@@ -240,6 +308,24 @@ def divide(self, x=None, var=None):
         unless var is provided. The grids must be the same.
     var: str
         A variable in the x to use for the operation
+
+    Examples
+    ------------
+
+    If you wanted to dividie all variables in a dataset by 20, you would do the following:
+
+    >>> data.divide(10)
+
+    To divide values in a dataset by those in the dataset data2 from a dataset data1, you would do the following:
+
+    >>> data1.divide(data2)
+
+    Grids in the datasets must match. Division will occur in matching timesteps in data1 and data2. If there is only 1 timestep in data2, then
+    the data from that timeste in data2 will divided the data in all data1 time steps.
+
+    Adding the data from another NetCDF file will work in the same way:
+
+    >>> data1.divide("example.nc")
     """
 
     # 1: int, float division
@@ -251,7 +337,10 @@ def divide(self, x=None, var=None):
     # get the netcdf file(s)
     if "api.DataSet" in str(type(x)):
         x.run()
-        ff = x.current
+        if len(x) == 1:
+            ff = x.current[0]
+        else:
+            raise TypeError("This can only work with single variable datasets")
     else:
         ff = x
 
