@@ -2,12 +2,13 @@ import copy
 import subprocess
 
 from nctoolkit.cleanup import cleanup
+from nctoolkit.session import remove_safe, append_safe
 from nctoolkit.runthis import run_this, tidy_command, run_cdo
 from nctoolkit.show import nc_variables
 from nctoolkit.temp_file import temp_file
 
 
-def cell_areas(self, join=True):
+def cell_area(self, join=True):
     """
     Calculate the area of grid cells.
     Area of grid cells is given in square meters.
@@ -15,7 +16,19 @@ def cell_areas(self, join=True):
     Parameters
     -------------
     join: boolean
-        Set to False if you only want the cell areas to be in the output. join=True adds the areas as a variable to the dataset. Defaults to True.
+        Set to False if you only want the cell areas to be in the output.
+        join=True adds the areas as a variable to the dataset. Defaults to True.
+
+    Examples
+    ------------
+    If you wanted to add the cell_areas as a new variable in a dataset, you would do the following:
+
+    >>> data.cell_area()
+
+    If you wanted to replace a dataset with the cell areas of that dataset, you would do the following:
+
+    >>> data.cell_area(join = False)
+
     """
 
     if isinstance(join, bool) is False:
@@ -41,9 +54,9 @@ def cell_areas(self, join=True):
 
         for ff in self:
 
-            if cdo_version in ["1.9.3", "1.9.4", "1.9.5"]:
+            if cdo_version in ["1.9.3", "1.9.4", "1.9.5", "1.9.6"]:
 
-                # things need to be done a bit differently in cdo < 1.9.6 because chaining doesn't work with merge
+                # in cdo < 1.9.6 chaining doesn't work with merge
 
                 if "cell_area" in nc_variables(ff):
                     raise ValueError("cell_area is already a variable")
@@ -53,6 +66,7 @@ def cell_areas(self, join=True):
                 cdo_command = f"cdo -gridarea {ff} {target1}"
                 cdo_command = tidy_command(cdo_command)
                 target1 = run_cdo(cdo_command, target1)
+                new_files.append(target1)
                 new_commands.append(cdo_command)
 
                 target = temp_file(".nc")
@@ -74,6 +88,7 @@ def cell_areas(self, join=True):
                 cdo_command = f"cdo -merge {ff} -gridarea {ff} {target}"
                 cdo_command = tidy_command(cdo_command)
                 target = run_cdo(cdo_command, target)
+
                 new_files.append(target)
 
                 new_commands.append(cdo_command)
@@ -83,6 +98,9 @@ def cell_areas(self, join=True):
 
         self.current = new_files
 
+        for ff in new_files:
+            remove_safe(ff)
+
         self._hold_history = copy.deepcopy(self.history)
 
         cleanup()
