@@ -5,29 +5,36 @@ import subprocess
 
 def centre(self, by ="latitude", by_area = False):
     """
-    Calculate the zonal mean for each year/month combination in files.
+    Calculate the latitudinal or longitudinal centre for each year/month combination in files.
     This applies to each file in an ensemble.
+    by : str
+        Set to 'latitude' if you want the latitiduinal centre calculated. 'longitude' for longitudinal.
+    by_area : bool
+        If the variable is a value/m2 type variable, set to True, otherwise set to False.
     """
 
     if by not in ["longitude", "latitude"]:
         raise ValueError("by is not valid. Please check!")
+
     if type(by_area) is not bool:
-        raise ValueError("by_area is not boolean. Please check!")
+        raise TypeError("by_area is not boolean. Please check!")
 
     self.run()
 
-    if type(self.current) is list:
+    if len(self) >1:
         raise TypeError("This method still does not work with lists! Consider merging.")
 
     data1 = self.copy()
-    ops = dict()
+    ops = []
     for var in self.variables:
         if by == "latitude":
-            ops[var] = (f"{var}*clat({var})")
+            ops.append(f"{var}={var}*clat({var})")
         else:
-            ops[var] = (f"{var}*clon({var})")
+            ops.append(f"{var}={var}*clon({var})")
 
-    self.transmute(ops)
+    ops = ";".join(ops)
+    ops = f"expr,'{ops}'"
+    self.cdo_command(ops)
     data1.spatial_sum(by_area = by_area)
     self.spatial_sum(by_area = by_area)
     self.divide(data1)
