@@ -4,6 +4,7 @@ from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_cdo, tidy_command
 from nctoolkit.show import nc_variables
 from nctoolkit.temp_file import temp_file
+from nctoolkit.session import nc_safe, remove_safe, get_safe
 
 
 def cor(self, var1=None, var2=None, method="fld"):
@@ -55,6 +56,10 @@ def cor(self, var1=None, var2=None, method="fld"):
 
     self.current = new_files
 
+    for ff in new_files:
+        if len([x for x in get_safe() if x == ff]) > 1:
+            remove_safe(ff)
+
     # tidy up the attributes of the netcdf file in the dataset
     self.rename({var1: "cor"})
     self.set_units({"cor": "-"})
@@ -67,7 +72,8 @@ def cor(self, var1=None, var2=None, method="fld"):
 def cor_space(self, var1=None, var2=None):
     """
     Calculate the correlation correct between two variables in space
-    This is calculated for each time step. The correlation coefficient coefficient is calculated using values in all grid cells, ignoring missing values.
+    This is calculated for each time step. The correlation coefficient coefficient is
+    calculated using values in all grid cells, ignoring missing values.
 
     Parameters
     -------------
@@ -75,6 +81,17 @@ def cor_space(self, var1=None, var2=None):
         The first variable
     var2: str
         The second variable
+
+    Examples
+    ------------
+
+    If you wanted to calculate the spatial correlation coefficient between variables x and y in a dataset, you would do this:
+
+    >>> data.cor_space("x", "y")
+
+    The correlation coefficient will be calculated for each time step.
+
+
     """
 
     cor(self, var1=var1, var2=var2, method="fld")
@@ -91,5 +108,15 @@ def cor_time(self, var1=None, var2=None):
         The first variable
     var2: str
         The second variable
+
+    Examples
+    ------------
+
+    If you wanted to calculate the temporal correlation coefficient between variables x and y in a dataset, you would do this:
+
+    >>> data.cor_space("x", "y")
+
+    The correlation coefficient will be calculated for each grid cell.  This method will indicate how temporally correlated variables are
+    in different spatial regions.
     """
     cor(self, var1=var1, var2=var2, method="tim")
