@@ -4,14 +4,14 @@ import os
 # function to find files in directory with a specified variable
 
 
-def create_ensemble(path="", var=None, recursive=True):
+def create_ensemble(path="", recursive=True):
     """
     Generate an ensemble
 
     Parameters
     -------------
     path: str
-        The system to search for netcdf files
+        The directory to search for netcdf files
     recursive : boolean
         True/False depending on whether you want to search the path recursively.
         Defaults to True.
@@ -20,6 +20,20 @@ def create_ensemble(path="", var=None, recursive=True):
     -------------
     list
         A list of files
+
+    Examples
+    ------------
+
+    If you wanted to recursively find all NetCDF files available in a directory "data", you would do this:
+
+    >>> import nctoolkit as nc
+    >>> nc.create_ensemble("data")
+
+    If you wanted to find the files in that directory and ignore subdirectories, you would instead do this:
+
+    >>> nc.create_ensemble("data", recursive = False)
+
+
     """
 
     # make sure the path exists
