@@ -6,6 +6,7 @@ from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
 from nctoolkit.runthis import run_this, run_nco
 from nctoolkit.temp_file import temp_file
+from nctoolkit.session import get_safe, remove_safe
 
 
 def cdo_version():
@@ -47,7 +48,7 @@ def ensemble_percentile(self, p=None):
     self.run()
 
     # Throw an error if there is only a single file in the tracker
-    if type(self.current) is not list:
+    if len(self) == 1:
         warnings.warn(message="There is only one file in the dataset")
 
     # create the cdo command and run it
@@ -66,9 +67,6 @@ def ensemble_nco(self, method, ignore_time=False):
 
     ff_ensemble = copy.deepcopy(self.current)
 
-    if type(self.current) is str:
-        ff_ensemble = [copy.deepcopy(self.current)]
-
     # generate a temp files
     target = temp_file("nc")
 
@@ -81,12 +79,20 @@ def ensemble_nco(self, method, ignore_time=False):
     # run the call
     target = run_nco(nco_command, target)
 
+    if target in get_safe():
+        remove_target = True
+    else:
+        remove_target = False
+
     # add the call to the history and tempfile to nc_safe
     self.history.append(nco_command)
     self._hold_history = copy.deepcopy(self.history)
 
     self.current = target
 
+    if remove_target:
+        remove_safe(target)
+
     self._merged = True
 
     cleanup()
@@ -111,7 +117,7 @@ def ensemble_max(self, nco=False, ignore_time=False):
     if nco is False:
         self.run()
 
-        if type(self.current) is not list:
+        if len(self) == 1:
             warnings.warn(message="There is only one file in the dataset")
 
         if ignore_time is False:
@@ -149,7 +155,7 @@ def ensemble_min(self, nco=False, ignore_time=False):
         calculated for each time steps; for example, if the ensemble is made up of
         monthly files the min for each month will be calculated.
     """
-    if type(self.current) is not list:
+    if len(self) == 1:
         warnings.warn(message="There is only one file in the dataset")
 
     if nco is False:
@@ -194,7 +200,7 @@ def ensemble_mean(self, nco=False, ignore_time=False):
     if nco is False:
         self.run()
 
-        if type(self.current) is not list:
+        if len(self) == 1:
             warnings.warn(message="There is only one file in the dataset")
 
         if ignore_time is False:
@@ -225,7 +231,7 @@ def ensemble_range(self):
     """
     self.run()
 
-    if type(self.current) is not list:
+    if len(self) == 1:
         warnings.warn(message="There is only one file in the dataset")
 
     cdo_command = "cdo --sortname -ensrange"
@@ -242,7 +248,7 @@ def ensemble_sum(self):
     """
     self.run()
 
-    if type(self.current) is not list:
+    if len(self) == 1:
         warnings.warn(message="There is only one file in the dataset")
 
     cdo_command = "cdo --sortname -enssum"
