@@ -4,6 +4,7 @@ import subprocess
 from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_this, run_cdo, tidy_command
 from nctoolkit.temp_file import temp_file
+from nctoolkit.session import nc_safe, remove_safe
 
 
 def cdo_version():
@@ -32,6 +33,18 @@ def spatial_mean(self):
     """
     Calculate the area weighted spatial mean for all variables
     This is performed for each time step.
+
+    Examples
+    ------------
+
+    If you want to calculate the spatial mean for a dataset, just do the following:
+
+    >>> data.spatial_mean()
+
+    Note that this calculation will calculate the average using weights based on each cell's
+    area. If cell areas cannot be calculated, it will take a straight average, and a warning
+    will say this.
+
     """
     fldstat(self, stat="mean")
 
@@ -40,6 +53,14 @@ def spatial_min(self):
     """
     Calculate the spatial minimum for all variables
     This is performed for each time step.
+
+    Examples
+    ------------
+
+    If you want to calculate the spatial minimum for a dataset, just do the following:
+
+    >>> data.spatial_min()
+
     """
     fldstat(self, stat="min")
 
@@ -48,6 +69,13 @@ def spatial_max(self):
     """
     Calculate the spatial maximum for all variables
     This is performed for each time step.
+
+    Examples
+    ------------
+    If you want to calculate the spatial maximum for a dataset, just do the following:
+
+    >>> data.spatial_max()
+
     """
     fldstat(self, stat="max")
 
@@ -56,6 +84,12 @@ def spatial_range(self):
     """
     Calculate the spatial range for all variables
     This is performed for each time step.
+
+    Examples
+    ------------
+    If you want to calculate the range of each variable across space for a dataset, just do the following:
+
+    >>> data.spatial_max()
     """
     fldstat(self, stat="range")
 
@@ -68,7 +102,25 @@ def spatial_sum(self, by_area=False):
     Parameters
     --------------
     by_area : boolean
-        Set to True if you want to multiply the values by the grid cell area before summing over space. Default is False.
+        Set to True if you want to multiply the values by the grid cell area
+        before summing over space. Default is False.
+
+    Examples
+    ------------
+    If you want to calculate the spatial sum each variable across space for a dataset, just do the following:
+
+    >>> data.spatial_sum()
+
+    By default, this method simply sums up each grid cell value. In some cases this is not suitable. For example,
+    the values in each cell may concentrations or values per square metre etc. In this case multiplying each cell
+    value by the cell area is more suitable. Do the following:
+
+    >>> data.spatial_sum(by_area = True)
+
+    Each cell's value will be multiplied by the area of the cell (in square metres) prior to calculating the
+    spatial sum.
+
+
     """
 
     if isinstance(by_area, bool) is False:
@@ -78,7 +130,7 @@ def spatial_sum(self, by_area=False):
     if cdo_version() in ["1.9.3"]:
         self.run()
 
-    if (type(self.current)) is str or (by_area is False):
+    if len(self) == 1 or (by_area is False):
 
         if by_area:
             self.run()
@@ -88,14 +140,14 @@ def spatial_sum(self, by_area=False):
                 new_commands = []
                 target1 = temp_file("nc")
 
-                cdo_command = f"cdo -gridarea {self.current} {target1}"
+                cdo_command = f"cdo -gridarea {self.current[0]} {target1}"
                 cdo_command = tidy_command(cdo_command)
                 new_commands.append(cdo_command)
                 target1 = run_cdo(cdo_command, target=target1)
 
                 target2 = temp_file("nc")
 
-                cdo_command = f"cdo -mul {self.current} {target1} {target2}"
+                cdo_command = f"cdo -mul {self.current[0]} {target1} {target2}"
                 cdo_command = tidy_command(cdo_command)
                 new_commands.append(cdo_command)
 
@@ -114,7 +166,7 @@ def spatial_sum(self, by_area=False):
 
                 return None
             else:
-                cdo_command = f"cdo -fldsum -mul {self.current} -gridarea "
+                cdo_command = f"cdo -fldsum -mul {self.current[0]} -gridarea "
         else:
             cdo_command = "cdo -fldsum"
 
@@ -165,6 +217,9 @@ def spatial_sum(self, by_area=False):
 
     self.current = new_files
 
+    for ff in new_files:
+        remove_safe(ff)
+
     cleanup()
     self.disk_clean()
 
@@ -177,7 +232,13 @@ def spatial_percentile(self, p=None):
     -------------
     p: int or float
         Percentile to calculate. 0<=p<=100.
-    """
+
+    Examples
+    ------------
+    If you want to calculate the median of each variable across space for a dataset, just do the following:
+
+    >>> data.spatial_percentile(50)
+ """
 
     if p is None:
         raise ValueError("Please supply a percentile")
