@@ -4,19 +4,27 @@ from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_cdo, tidy_command
 from nctoolkit.show import nc_years
 from nctoolkit.temp_file import temp_file
+from nctoolkit.api import open_data
+from nctoolkit.session import nc_safe, remove_safe
+from nctoolkit.show import nc_variables
 
 
 def phenology(self, var=None, metric=None, p=None):
     """
     Calculate phenologies from a dataset
-    Each file in an ensemble must only cover a single year, and ideally have all days. The method assumes datasets have daily resolution.
+    Each file in an ensemble must only cover a single year, and ideally have all days.
+    The method assumes datasets have daily resolution.
 
     Parameters
     -------------
     var : str
         Variable to analyze.
     metric : str
-        Must be peak, middle, start or end. Peak is defined as the day of the maximum value. Middle is the day when the cumulative total of the variable first exceeds the cumulative total for the entire year. Start or end is defined as the first day when the cumulative total exceeds a percentile p of the maximum cumulative total.
+        Must be peak, middle, start or end. Peak is defined as the day of the maximum
+        value.  Middle is the day when the cumulative total of the variable first
+        exceeds the cumulative total for the entire year. Start or end is defined as
+        the first day when the cumulative total exceeds a percentile p of the maximum
+        cumulative total.
     p : str
         Percentile to use for start or end.
     """
@@ -24,6 +32,9 @@ def phenology(self, var=None, metric=None, p=None):
     if metric is None:
         raise ValueError("No metric was supplied!")
 
+    if metric not in ["peak", "middle", "start", "end"]:
+        raise ValueError(f"{metric} is not a valid metric")
+
     if var is None:
         raise ValueError("No var was supplied")
     if type(var) is not str:
@@ -31,17 +42,30 @@ def phenology(self, var=None, metric=None, p=None):
 
     self.run()
 
+    # split data into separate years if needed
+    split_files = False
+    for ff in self:
+        if len(nc_years(ff)) > 1:
+            split_files = True
+
+    for ff in self:
+        if var not in nc_variables(ff):
+            raise ValueError(f"{var} is not a valid variable!")
+
+    if split_files:
+        self.split("year")
+
     if metric == "peak":
 
         new_files = []
         new_commands = []
 
         for ff in self:
-            if len(nc_years(ff)) > 1:
-                raise ValueError("This can only work with single year data currently")
 
             target = temp_file(".nc")
-            command = f"cdo -timmin -setrtomiss,-10000,0 -expr,'peak=var*ctimestep()' -eq -chname,{var},var -selname,{var} {ff} -timmax -chname,{var},var -selname,{var} {ff} {target}"
+            command = f"cdo -timmin -setrtomiss,-10000,0 -expr,'peak=var*ctimestep()' "\
+                f"-eq -chname,{var},var -selname,{var} {ff} -timmax -chname,{var},var "\
+                f"-selname,{var} {ff} {target}"
 
             command = tidy_command(command)
             target = run_cdo(command, target=target)
@@ -54,6 +78,9 @@ def phenology(self, var=None, metric=None, p=None):
 
         self.current = new_files
 
+        for ff in new_files:
+            remove_safe(ff)
+
         cleanup()
         return None
 
@@ -80,11 +107,11 @@ def phenology(self, var=None, metric=None, p=None):
 
         for ff in self:
 
-            if len(nc_years(ff)) > 1:
-                raise ValueError("This can only work with single year data currently")
-
             target = temp_file(".nc")
-            command = f"cdo -timmin -setrtomiss,-10000,0 -expr,'{metric}=var*ctimestep()' -gt -timcumsum -chname,{var},var -selname,{var} {ff} -mulc,{start} -timsum -chname,{var},var -selname,{var} {ff} {target}"
+            command = f"cdo -timmin -setrtomiss,-10000,0 -expr,"\
+                      f"'{metric}=var*ctimestep()' -gt -timcumsum -chname,{var},var "\
+                      f"-selname,{var} {ff} -mulc,{start} -timsum -chname,{var},var "\
+                      f"-selname,{var} {ff} {target}"
 
             command = tidy_command(command)
             target = run_cdo(command, target=target)
@@ -97,8 +124,14 @@ def phenology(self, var=None, metric=None, p=None):
 
         self.current = new_files
 
+        for ff in new_files:
+            remove_safe(ff)
+
         cleanup()
 
         return None
 
-    raise ValueError("You have not supplied a valid metric")
+
+
+
+
