@@ -8,7 +8,7 @@ from nctoolkit.api import open_data
 from nctoolkit.cleanup import cleanup
 from nctoolkit.generate_grid import generate_grid
 from nctoolkit.runthis import run_this, run_cdo
-from nctoolkit.session import nc_safe
+from nctoolkit.session import nc_safe, append_safe, remove_safe
 from nctoolkit.temp_file import temp_file
 
 
@@ -26,6 +26,7 @@ def regrid(self, grid=None, method="bil"):
         nearest neighbour - "nn" - "nearest neighbour"; "bic" - "bicubic interpolation".
     """
 
+
     del_grid = None
     if grid is None:
         raise ValueError("No grid was supplied")
@@ -43,11 +44,8 @@ def regrid(self, grid=None, method="bil"):
 
     if "DataSet" in str(type(grid)):
         grid.run()
-        if type(grid.current) is str:
-            grid = grid.current
-        else:
-            grid = grid.current[0]
-            warnings.warn(message="The first file in dataset used for regridding!")
+        grid = grid.current[0]
+        warnings.warn(message="The first file in dataset used for regridding!")
         grid_type = "nc"
 
     if grid_type is None:
@@ -83,11 +81,12 @@ def regrid(self, grid=None, method="bil"):
         if grid_type == "df":
             target_grid = generate_grid(grid)
             del_grid = copy.deepcopy(target_grid)
-            nc_safe.append(del_grid)
+            append_safe(del_grid)
         else:
             target_grid = grid
     new_files = []
 
+
     for key in grid_split:
         # first we need to generate the weights for remapping
         # and add this to the files created list and self.weights
@@ -97,49 +96,42 @@ def regrid(self, grid=None, method="bil"):
 
         weights_nc = temp_file("nc")
 
-        if type(tracker.current) is list:
-            cdo_command = (
-                f"cdo -gen{method},{target_grid} {tracker.current[0]} {weights_nc}"
-            )
-        else:
-            cdo_command = (
-                f"cdo -gen{method},{target_grid} {tracker.current} {weights_nc}"
-            )
+        cdo_command = (
+            f"cdo -gen{method},{target_grid} {tracker.current[0]} {weights_nc}"
+        )
 
-        weights_nc = run_cdo(cdo_command, target=weights_nc)
+        try:
+            weights_nc = run_cdo(cdo_command, target=weights_nc)
+        except Exception as e:
+            del tracker
+            remove_safe(weights_nc)
+            raise ValueError(e)
 
         cdo_command = f"cdo -remap,{target_grid},{weights_nc}"
 
         tracker._execute = True
 
-        nc_safe.append(weights_nc)
-
         run_this(cdo_command, tracker, output="ensemble")
 
-        nc_safe.remove(weights_nc)
+        remove_safe(weights_nc)
 
-        if type(tracker.current) is str:
-            new_files += [tracker.current]
-        else:
-            new_files += tracker.current
 
-        for ff in new_files:
-            nc_safe.append(ff)
+        new_files += tracker.current
+
 
         self.history += tracker.history
 
         self._hold_history = copy.deepcopy(self.history)
 
-    if del_grid is not None:
-        if del_grid in nc_safe:
-            nc_safe.remove(del_grid)
 
-    for ff in new_files:
-        if ff in nc_safe:
-            nc_safe.remove(ff)
+
+    if del_grid is not None:
+        remove_safe(del_grid)
+
 
     self.current = new_files
 
+
     self._thredds = False
     cleanup()
     self.disk_clean()
