@@ -1,17 +1,26 @@
 from nctoolkit.cleanup import cleanup
 from nctoolkit.runthis import run_this
-from nctoolkit.session import nc_safe
+from nctoolkit.session import nc_safe, remove_safe
 import warnings
 
 
 def run(self):
     """
     Run all stored commands in a dataset
+
+    Examples
+    ------------
+    If evaluation is lazy and you need to evaluate commands on a dataset, do the following:
+
+    >>> data.run()
+
     """
 
     # the first step is to set the run status to true
 
-    if (self._execute is False) and (len(self.history) > len(self._hold_history)):
+    if (self._execute is False) and (
+        len(self.history) > len(self._hold_history) or self._zip or self._format is not None
+    ):
         self._execute = True
 
         cdo_command = "cdo "
@@ -30,10 +39,10 @@ def run(self):
 
         if len(self._safe) > 0:
             for ff in self._safe:
-                if ff in nc_safe:
-                    nc_safe.remove(ff)
+                remove_safe(ff)
 
         self._safe = []
 
         cleanup()
 
+        self._ncommands = 0
