@@ -1,6 +1,7 @@
 import os
 
-from nctoolkit.session import session_info, nc_safe, temp_dirs, temp_files
+from nctoolkit.session import session_info, nc_safe, get_tempdirs, get_safe
+import warnings
 
 
 def nc_remove(ff, deep=False):
@@ -11,7 +12,7 @@ def nc_remove(ff, deep=False):
 
     unsafe = True
 
-    for directory in temp_dirs:
+    for directory in get_tempdirs():
         if ff.startswith(directory):
             unsafe = False
 
@@ -21,15 +22,21 @@ def nc_remove(ff, deep=False):
     if "nctoolkit" not in ff:
         raise ValueError(f"The file {ff}  was not created by nctoolkit")
 
-    if (ff in nc_safe) and (deep is False):
-        raise ValueError(f"The file {ff} is in the safe list, so cannot be removed")
+    # If things are running in parallel it's possible nc_safe was updated after files to delete
+    # were generated....
+    if (ff in get_safe()) and (deep is False):
+        return None
 
-    possibles = [os.path.basename(x) for x in temp_files]
-    if os.path.basename(ff) not in possibles:
-        raise ValueError(f"{ff} is not a temp file created by nctoolkit")
+    if (deep is False):
+        for ss in list(get_safe()):
+            if ss in ff:
+                return None
 
     if deep is False:
         if session_info["stamp"] not in ff:
             raise ValueError(f"The file {ff}  was not created during this session")
 
-    os.remove(ff)
+    try:
+        os.remove(ff)
+    except:
+        x = "1"
