@@ -27,6 +27,14 @@ def rolling_mean(self, window=None):
     -------------
     window = int
         The size of the window for the calculation of the rolling mean
+
+    Examples
+    ------------
+
+    If you wanted to calculate a rolling mean with the mean calculated over every 10 time steps, do the following:
+
+    >>> data.rolling_mean(10)
+
     """
     rollstat(self, window=window, stat="mean")
 
@@ -39,6 +47,13 @@ def rolling_min(self, window=None):
     -------------
     window = int
         The size of the window for the calculation of the rolling minimum
+
+    Examples
+    ------------
+
+    If you wanted to calculate a rolling minimum with the minimum calculated over every 10 time steps, do the following:
+
+    >>> data.rolling_min(10)
     """
     rollstat(self, window=window, stat="min")
 
@@ -51,6 +66,12 @@ def rolling_max(self, window=None):
     -------------
     window = int
         The size of the window for the calculation of the rolling maximum
+    Examples
+    ------------
+
+    If you wanted to calculate a rolling maximum with the maximum calculated over every 10 time steps, do the following:
+
+    >>> data.rolling_max(10)
     """
     rollstat(self, window=window, stat="max")
 
@@ -63,6 +84,13 @@ def rolling_range(self, window=None):
     -------------
     window = int
         The size of the window for the calculation of the rolling range
+
+    Examples
+    ------------
+
+    If you wanted to calculate a rolling range with the range calculated over every 10 time steps, do the following:
+
+    >>> data.rolling_range(10)
     """
     rollstat(self, window=window, stat="range")
 
@@ -75,5 +103,12 @@ def rolling_sum(self, window=None):
     -------------
     window = int
         The size of the window for the calculation of the rolling sum
+
+    Examples
+    ------------
+
+    If you wanted to calculate a rolling sum with the sum calculated over every 10 time steps, do the following:
+
+    >>> data.rolling_sum(10)
     """
     rollstat(self, window=window, stat="sum")
