@@ -8,7 +8,13 @@ import multiprocessing
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.session import nc_protected, session_info
+from nctoolkit.session import (
+    nc_protected,
+    session_info,
+    append_safe,
+    remove_safe,
+    get_protected
+)
 from nctoolkit.temp_file import temp_file
 
 
@@ -50,9 +56,13 @@ def tidy_command(command):
 
 def run_nco(command, target, out_file=None, overwrite=False):
     command = command.strip()
+    append_safe(target)
+    original_target = target
     if (
         command.startswith("ncea ")
         or command.startswith("ncra ")
+        or command.startswith("ncap ")
+        or command.startswith("ncap2 ")
         or command.startswith("ncks ")
         or command.startswith("ncatted")
     ) is False:
@@ -60,7 +70,7 @@ def run_nco(command, target, out_file=None, overwrite=False):
 
     # Make sure it is not attempting to overwrite a protected file
     if out_file is None:
-        if command.split()[-1] in nc_protected:
+        if command.split()[-1] in get_protected():
             if overwrite is False:
                 raise ValueError("Attempting to overwrite an opened file")
 
@@ -74,7 +84,9 @@ def run_nco(command, target, out_file=None, overwrite=False):
                 if target.startswith("/tmp"):
                     new_target = target.replace("/tmp/", "/var/tmp/")
                     command = command.replace(target, new_target)
-                    target = target.replace("/tmp/", "/var/tmp/")
+                    remove_safe(target)
+                    target = new_target
+                    append_safe(target)
 
     out = subprocess.Popen(
         command,
@@ -94,7 +106,10 @@ def run_nco(command, target, out_file=None, overwrite=False):
         if target.startswith("/tmp/"):
             new_target = target.replace("/tmp/", "/var/tmp/")
             command = command.replace(target, new_target)
+            append_safe(new_target)
+            remove_safe(target)
             target = new_target
+
             out = subprocess.Popen(
                 command,
                 shell=True,
@@ -104,6 +119,7 @@ def run_nco(command, target, out_file=None, overwrite=False):
             )
             result1, ignore = out.communicate()
             if "ERROR" in str(result1):
+                remove_safet(target)
                 raise ValueError(
                     str(result1).replace("b'", "").replace("\\n", "").replace("'", "")
                 )
@@ -116,10 +132,12 @@ def run_nco(command, target, out_file=None, overwrite=False):
 
     if target != "":
         if os.path.exists(target) is False:
+            remove_safe(target)
             raise ValueError(f"{command} was not successful. Check output")
     else:
         actual_target = command.split(" ")[-1].strip()
         if os.path.exists(actual_target) is False:
+            remove_safe(target)
             raise ValueError(f"{command} was not successful. Check output")
 
     if target != "":
@@ -133,6 +151,7 @@ def run_cdo(command, target, out_file=None, overwrite=False):
     # make sure the output file does not exist
 
     command = tidy_command(command)
+    start_target = target
 
     if out_file is None:
         if os.path.exists(command.split()[-1]):
@@ -150,6 +169,7 @@ def run_cdo(command, target, out_file=None, overwrite=False):
                     new_target = target.replace("/tmp/", "/var/tmp/")
                     command = command.replace(target, new_target)
                     target = target.replace("/tmp/", "/var/tmp/")
+    append_safe(target)
 
     if command.startswith("cdo ") is False:
         raise ValueError("The command does not start with cdo!")
@@ -164,8 +184,64 @@ def run_cdo(command, target, out_file=None, overwrite=False):
     out.wait()
     result, ignore = out.communicate()
 
+    # this will potentially fail because of floating point precision. A quick fix to see if that is the case....
+
+    if "Use the CDO option -b F32" in (result.decode("utf-8")):
+        command_chunks = command.split(" ")
+
+        i = 0
+        change = None
+        for cc in command_chunks:
+            i += 1
+            if "-b" == cc.strip():
+                change = i
+        if change is not None:
+            command_chunks[change] = "F32"
+            command = str_flatten(command_chunks, " ")
+        else:
+            command = command.replace("cdo ", "cdo -b F32 ")
+        command
+
+        out = subprocess.Popen(
+            command,
+            shell=True,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+        )
+        out.wait()
+        result, ignore = out.communicate()
+
+    if "Use the CDO option -b F32" in (result.decode("utf-8")):
+        command_chunks = command.split(" ")
+
+        i = 0
+        change = None
+        for cc in command_chunks:
+            i += 1
+            if "-b" == cc.strip():
+                change = i
+        if change is not None:
+            command_chunks[change] = "F32"
+            command = str_flatten(command_chunks, " ")
+        else:
+            command = command.replace("cdo ", "cdo -b F64 ")
+        command
+
+        out = subprocess.Popen(
+            command,
+            shell=True,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+        )
+        out.wait()
+        result, ignore = out.communicate()
+
     if out_file is not None:
         if "HDF5 library version mismatched error" in str(result):
+            remove_safe(target)
+            remove_safe(start_target)
             raise ValueError(
                 "The HDF5 header files used to compile this application do not match "
                 "the version used by the HDF5 library to which this application is "
@@ -177,6 +253,8 @@ def run_cdo(command, target, out_file=None, overwrite=False):
             or ("HDF error" in str(result))
             or (out.returncode != 0)
         ):
+            remove_safe(target)
+            remove_safe(start_target)
             raise ValueError(
                 str(result).replace("b'", "").replace("\\n", "").replace("'", "")
             )
@@ -184,20 +262,24 @@ def run_cdo(command, target, out_file=None, overwrite=False):
             return out_file
 
     if ("sellonlat" in command) and ("std::bad_alloc" in str(result)):
+        remove_safe(target)
+        remove_safe(start_target)
         raise ValueError(
-            "Is the horizontal grid very large? Consider setting cdo=False in clip!"
+            "Is the horizontal grid very large? Consider setting cdo=False in crop!"
         )
 
     if "(Abort)" in str(result):
+        remove_safe(target)
+        remove_safe(start_target)
         raise ValueError(
             str(result).replace("b'", "").replace("\\n", "").replace("'", "")
         )
 
     if "HDF5 library version mismatched error" in str(result):
         raise ValueError(
-                "The HDF5 header files used to compile this application do not match "
-                "the version used by the HDF5 library to which this application is "
-                "linked. This is likely because of a conda problem."
+            "The HDF5 header files used to compile this application do not match "
+            "the version used by the HDF5 library to which this application is "
+            "linked. This is likely because of a conda problem."
         )
 
     if (
@@ -209,6 +291,7 @@ def run_cdo(command, target, out_file=None, overwrite=False):
             new_target = target.replace("/tmp/", "/var/tmp/")
             command = command.replace(target, new_target)
             target = new_target
+            append_safe(target)
 
             out = subprocess.Popen(
                 command,
@@ -225,12 +308,16 @@ def run_cdo(command, target, out_file=None, overwrite=False):
                 or (out.returncode != 0)
             ):
                 if "Too many open files" in str(result1):
+                    remove_safe(target)
+                    remove_safe(start_target)
                     raise ValueError(
-                            "There are too many open files in CDO. Check the files "
-                            "your OS allows to be open simultaneously in the Bourne "
-                            "shell with 'ulimit -n'"
+                        "There are too many open files in CDO. Check the files "
+                        "your OS allows to be open simultaneously in the Bourne "
+                        "shell with 'ulimit -n'"
                     )
                 else:
+                    remove_safe(target)
+                    remove_safe(start_target)
                     raise ValueError(
                         str(result1)
                         .replace("b'", "")
@@ -271,14 +358,14 @@ def run_cdo(command, target, out_file=None, overwrite=False):
 
             if len(missing_years) > 0:
                 warnings.warn(
-                    message=f'CDO warning: Years {str_flatten(missing_years, ",")} "\
-                            f"are missing',
+                    message=f'CDO warning: Years {str_flatten(missing_years, ",")} '
+                    "are missing",
                     stacklevel=2,
                 )
             if len(missing_months) > 0:
                 warnings.warn(
-                    message=f'CDO warning: Months {str_flatten(missing_months, ",")} "\
-                            f"are missing',
+                    message=f'CDO warning: Months {str_flatten(missing_months, ",")} '
+                    "are missing",
                     stacklevel=2,
                 )
     else:
@@ -315,18 +402,20 @@ def run_cdo(command, target, out_file=None, overwrite=False):
 
         if len(missing_years) > 0:
             warnings.warn(
-                message=f'CDO warning: Years {str_flatten(missing_years, ",")} "\
-                        f"are missing!',
+                message=f'CDO warning: Years {str_flatten(missing_years, ",")} '
+                "are missing!",
                 category=Warning,
             )
         if len(missing_months) > 0:
             warnings.warn(
-                message=f'CDO warning: Months {str_flatten(missing_months, ",")} "\
-                        f"are missing',
+                message=f'CDO warning: Months {str_flatten(missing_months, ",")} '
+                "are missing",
                 category=Warning,
             )
 
     if os.path.exists(target) is False:
+        remove_safe(target)
+        remove_safe(target)
         raise ValueError(f"{command} was not successful. Check output")
 
     session_info["latest_size"] = os.path.getsize(target)
@@ -336,9 +425,11 @@ def run_cdo(command, target, out_file=None, overwrite=False):
 
 def run_this(os_command, self, output="one", out_file=None):
 
+    self._ncommands += 1
+
     cores = session_info["cores"]
 
-    if type(self.current) is str:
+    if len(self) == 1:
         output = "ensemble"
 
     if self._execute is False:
@@ -350,24 +441,25 @@ def run_this(os_command, self, output="one", out_file=None):
 
     if self._execute:
 
-        if ((output == "ensemble") and (type(self.current) == list)) or (
-            (output == "ensemble") and (type(self.current) == str)
+        if ((output == "ensemble") and (len(self) > 1)) or (
+            (output == "ensemble") and (len(self) == 1)
         ):
             new_history = copy.deepcopy(self._hold_history)
 
-            if type(self.current) == str:
-                file_list = [self.current]
+            if len(self) == 1:
                 cores = 1
-            else:
-                file_list = self.current
+            file_list = self.current
 
             if len(self.history) > len(self._hold_history):
                 os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
                 os_command = os_command.replace("  ", " ")
 
-            pool = multiprocessing.Pool(cores)
-            target_list = []
-            results = dict()
+            if cores > 1:
+                pool = multiprocessing.Pool(cores)
+                target_list = []
+                results = dict()
+            else:
+                target_list = []
 
             for ff in file_list:
                 ff_command = os_command
@@ -381,6 +473,7 @@ def run_this(os_command, self, output="one", out_file=None):
 
                 if out_file is not None:
                     target = out_file
+
                 ff_command = f"{ff_command} {target}"
                 ff_command = ff_command.replace("  ", " ")
                 if " --sortname " in os_command:
@@ -397,36 +490,69 @@ def run_this(os_command, self, output="one", out_file=None):
 
                 ff_command = tidy_command(ff_command)
 
-                if self._zip:
-                    ff_command = ff_command.replace("cdo ", "cdo -z zip ")
+                zip_copy = False
+                if self._zip and self._ncommands == 1:
+                    zip_copy = True
+
+                format_it = False
+                if self._format is not None:
+                    format_it = True
+                    if self._ncommands == 1:
+                        ff_command = ff_command.replace(
+                            "cdo ", f"cdo -f {self._format} copy "
+                        )
+                    else:
+                        ff_command = ff_command.replace(
+                            "cdo ", f"cdo -f {self._format} "
+                        )
+
+                if self._zip and zip_copy and format_it == False:
+                    ff_command = ff_command.replace("cdo ", "cdo -z zip copy ")
+                else:
+                    if self._zip:
+                        ff_command = ff_command.replace("cdo ", "cdo -z zip ")
 
                 new_history.append(ff_command)
-                temp = pool.apply_async(run_cdo, [ff_command, target, out_file])
-                results[ff] = temp
 
-            pool.close()
-            pool.join()
-            for k, v in results.items():
-                target_list.append(v.get())
+                if cores > 1:
+                    temp = pool.apply_async(run_cdo, [ff_command, target, out_file])
+                    results[ff] = temp
+                else:
+                    target = run_cdo(ff_command, target, out_file)
+                    target_list.append(target)
 
-            if type(self.current) == str:
-                target_list = target_list[0]
+            if cores > 1:
+                pool.close()
+                pool.join()
+                for k, v in results.items():
+                    target_list.append(v.get())
 
             self.history = copy.deepcopy(new_history)
             self.current = copy.deepcopy(target_list)
 
+            if cores == 1 or session_info["parallel"]:
+                for ff in target_list:
+                    remove_safe(ff)
+
             self.disk_clean()
 
             cleanup()
+
             self._hold_history = copy.deepcopy(self.history)
 
+            self._zip = False
+
+            self._ncommands = 0
+
+            self._format = None
+
             return None
 
-        if (output == "one") and (type(self.current) == list):
+        if ((output == "one") and (len(self) > 1)) or self._zip == False:
 
             new_history = copy.deepcopy(self._hold_history)
 
-            file_list = [self.current]
+            file_list = self.current
 
             if len(self.history) > len(self._hold_history):
                 os_command = f'{os_command} {self.history[-1].replace("cdo ", " ")}'
@@ -437,7 +563,8 @@ def run_this(os_command, self, output="one", out_file=None):
                 all_sizes = 0
 
                 for ff in self:
-                    all_sizes += file_size(ff)
+                    if file_size(ff) is not None:
+                        all_sizes += file_size(ff)
 
                 result = os.statvfs("/tmp/")
                 result = result.f_frsize * result.f_bavail
@@ -453,8 +580,27 @@ def run_this(os_command, self, output="one", out_file=None):
             os_command = (
                 os_command + " " + str_flatten(self.current, " ") + " " + target
             )
-            if self._zip:
-                os_command = os_command.replace("cdo ", "cdo -z zip ")
+
+            zip_copy = False
+            if self._zip and self._ncommands == 1:
+                zip_copy = True
+
+            format_it = False
+
+            if self._format is not None:
+                format_it = True
+                if self._ncommands == 1:
+                    os_command = os_command.replace(
+                        "cdo ", f"cdo -f {self._format} copy "
+                    )
+                else:
+                    os_command = os_command.replace("cdo ", f"cdo -f {self._format} ")
+
+            if self._zip and zip_copy and format_it == False:
+                os_command = os_command.replace("cdo ", "cdo -z zip copy ")
+            else:
+                if self._zip:
+                    os_command = os_command.replace("cdo ", "cdo -z zip ")
 
             if "infile09178" in os_command:
                 os_command = os_command.replace(ff, "")
@@ -463,7 +609,11 @@ def run_this(os_command, self, output="one", out_file=None):
             os_command = tidy_command(os_command)
 
             target = run_cdo(os_command, target, out_file)
+
+            remove_safe(target)
+
             self.current = target
+
             self.history = new_history
             self.history.append(os_command)
 
@@ -472,3 +622,8 @@ def run_this(os_command, self, output="one", out_file=None):
             cleanup()
 
             self._hold_history = copy.deepcopy(self.history)
+
+            self._zip = False
+            self._n_commands = 0
+
+            self._format = None
