@@ -3,11 +3,12 @@ import warnings
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
 from nctoolkit.runthis import run_this
-from nctoolkit.session import nc_safe
 from nctoolkit.show import nc_years
+from nctoolkit.crop import crop
 
 
-def select_season(self, season=None):
+
+def select_seasons(self, season=None):
     """
     Select season from a dataset
 
@@ -33,7 +34,8 @@ def select_season(self, season=None):
 def select_months(self, months=None):
     """
     Select months from a dataset
-    This method will subset the dataset to only contain months within the list given. A warning message will be provided when there are missing months.
+    This method will subset the dataset to only contain months within the list given.
+    A warning message will be provided when there are missing months.
 
     Parameters
     -------------
@@ -50,7 +52,8 @@ def select_months(self, months=None):
 
     if type(months) is not list:
         months = [months]
-    # all of the variables in months need to be converted to ints, just in case floats have been provided
+    # all of the variables in months need to be converted to ints,
+    # just in case floats have been provided
 
     for x in months:
         if type(x) is not int:
@@ -67,7 +70,8 @@ def select_months(self, months=None):
 def select_years(self, years=None):
     """
     Select years from a dataset
-    This method will subset the dataset to only contain years within the list given. A warning message will be provided when there are missing years.
+    This method will subset the dataset to only contain years within the list given.
+    A warning message will be provided when there are missing years.
     Parameters
     -------------
     years : list,range or int
@@ -109,10 +113,9 @@ def select_years(self, years=None):
                 new_current.append(ff)
             if len(inter) == 0:
                 n_removed += 1
-                if ff in nc_safe:
-                    nc_safe.remove(ff)
 
-            # figure out if any of the files actually have years outide the period required
+            # figure out if any of the files actually have years
+            # outide the period required
             if len(inter) > 0:
                 if len([yy for yy in all_years if yy not in years]) > 0:
                     missing_files += 1
@@ -140,7 +143,7 @@ def select_years(self, years=None):
 
         cdo_command = f"cdo -selyear,{years}"
 
-        run_this(cdo_command, self, output="ensemble")
+        run_this(cdo_command, self, output="one")
 
     cleanup()
 
@@ -174,16 +177,19 @@ def select_variables(self, vars=None):
     run_this(cdo_command, self, output="ensemble")
 
 
-def select_timestep(self, times=None):
+
+def select_timesteps(self, times=None):
     """
     Select timesteps from a dataset
 
     Parameters
     -------------
     times : list or int
-        time step(s) to select. For example, if you wanted the first time step set times=0.
+        time step(s) to select. For example, if you wanted the first time step
+        set times=0.
     """
 
+
     if times is None:
         raise ValueError("Please supply times")
 
@@ -199,7 +205,8 @@ def select_timestep(self, times=None):
         if tt < 0:
             raise ValueError(f"{tt} is not a valid timestep")
 
-    # all of the variables in months need to be converted to ints, just in case floats have been provided
+    # all of the variables in months need to be converted to ints,
+    # just in case floats have been provided
 
     times = [int(x) + 1 for x in times]
     times = [str(x) for x in times]
@@ -208,3 +215,127 @@ def select_timestep(self, times=None):
     cdo_command = f"cdo -seltimestep,{times}"
 
     run_this(cdo_command, self, output="ensemble")
+
+
+def select(self, **kwargs):
+    """
+    A method for subsetting datasets to specific variables, years, longitudes etc.
+    Operations are applied in the order supplied.
+
+    Parameters
+    -------------
+    *kwargs
+        Possible arguments: variables, years, months, seasons, timesteps, lon, lat
+
+        Note: this uses partial matches. So year, month, var etc. will also work
+
+
+    Each kwarg works as follows:
+
+    variables : str or list
+        A variable or list of variables to select
+    seasons : str
+        Seasons to select. One of "DJF", "MAM", "JJA", "SON".
+    months : list, range or int
+        Month(s) to select.
+    years : list,range or int
+        Years(s) to select. These should be integers
+
+    timesteps : list or int
+        time step(s) to select. For example, if you wanted the first time step
+        set times=0.
+
+    Examples
+    ------------
+    If you want to select a single variable do the following:
+
+        >>> data.select(variable = "var")
+
+    If you want to select a list of variables, do this:
+
+        >>> data.select(variable = ["var1", "var2"])
+
+    If you want to select data for January, do the following:
+
+        >>> data.select(month = 1)
+
+    If you want to select a range of months, do the following:
+
+        >>> data.select(months = range(1, 7))
+
+    If you want to select a range of years, for example the 2010s, do the following:
+
+        >>> data.select(years = range(2010, 2020))
+
+    If you want to select the first two timesteps in a dataset, do the following:
+
+        >>> data.select(timesteps = [0,1])
+
+
+    """
+
+    non_selected = True
+
+    for key in kwargs:
+
+        if "var" in key:
+            select_variables(self, kwargs[key])
+            #self.select_variables(kwargs[key])
+            non_selected = False
+
+        if "mon" in  key:
+            #self.select_months(kwargs[key])
+            select_months(self, kwargs[key])
+            non_selected = False
+
+        if "year" in key:
+            select_years(self, kwargs[key])
+            #self.select_years(kwargs[key])
+            non_selected = False
+
+        if "seas" in key:
+            #self.select_seasons(kwargs[key])
+            select_seasons(self, kwargs[key])
+            non_selected = False
+
+        if "time" in key:
+            #self.select_timesteps(kwargs[key])
+            select_timesteps(self, kwargs[key])
+            non_selected = False
+
+    ## Now we need to get crop working
+
+
+    #crop_it = False
+    #lon = None
+    #lat = None
+    #nco = False
+    #nco_vars = None
+    #for key in kwargs:
+    #    if "lon" == key:
+    #        non_selected = False
+    #        crop_it = True
+    #        lon = kwargs[key]
+    #    if "lat" == key:
+    #        non_selected = False
+    #        crop_it = True
+    #        lat = kwargs[key]
+    #    if "nco" == key:
+    #        nco = kwargs[key]
+    #    if "nco_vars" == key:
+    #        nco_vars = kwargs[key]
+
+    #if crop_it:
+    #    if lon is not None and lat is not None:
+    #        self.crop(lon = lon, lat = lat, nco = nco, nco_vars = nco_vars)
+    #    if lon is not None and lat is None:
+    #        self.crop(lon = lon,  nco = nco, nco_vars = nco_vars)
+    #    if lon is None and lat is not None:
+    #        self.crop(lat = lat,  nco = nco, nco_vars = nco_vars)
+
+
+
+    if non_selected:
+        raise AttributeError(f"{key} is not a valid select method")
+
+
