@@ -5,7 +5,7 @@ import platform
 
 from nctoolkit.cleanup import cleanup
 from nctoolkit.temp_file import temp_file
-from nctoolkit.session import session_info, temp_dirs
+from nctoolkit.session import session_info, get_tempdirs,  append_safe, remove_safe
 
 
 def split_cdo(self, method="year"):
@@ -19,11 +19,12 @@ def split_cdo(self, method="year"):
 
     commands = []
 
+    bases = []
+
     for ff in self:
 
         # We need to split the file by name
-
-        # But, first we need to check whether there is sufficient space in the output folder
+        # But, first we need to check if there is space in the output folder
         # If there isn't, we need to switch to the /var/tmp
 
         if platform.system() == "Linux":
@@ -36,6 +37,11 @@ def split_cdo(self, method="year"):
                     session_info["temp_dir"] = "/var/tmp/"
 
         split_base = temp_file()
+        bases.append(split_base)
+
+        # add split base to the save list in case splitting fails. This means they can be cleared up later
+
+        append_safe(split_base)
 
         cdo_command = f"cdo -s -split{method} {ff} {split_base}"
 
@@ -46,7 +52,7 @@ def split_cdo(self, method="year"):
         # now, pull out the files generated
 
         counter = 0
-        for directory in temp_dirs:
+        for directory in get_tempdirs():
             mylist = [f for f in glob.glob(f"{directory}/*.nc*")]
             mylist = [f for f in mylist if session_info["stamp"] in f]
             for ff in mylist:
@@ -63,6 +69,12 @@ def split_cdo(self, method="year"):
     self._merged = False
     self.current = new_files
 
+    # remove the bases from the split list. This is for parallel processing
+
+    for ff in bases:
+        remove_safe(ff)
+
+
     cleanup()
     self.disk_clean()
 
@@ -70,12 +82,29 @@ def split_cdo(self, method="year"):
 def split(self, by=None):
     """
     Split the dataset
-    Each file in the ensemble will be separated into new files based on the splitting argument.
+    Each file in the ensemble will be separated into new files based on the
+    splitting argument.
 
     Parameters
     --------------------
     by : str
-        Available by arguments are 'year', 'month', 'yearmonth', 'season', 'day'. year will split files by year, month will split files by month, yearmonth will split files by year and month; season will split files by year, day will split files by day.
+        Available by arguments are 'year', 'month', 'yearmonth', 'season', 'day'.
+        year will split files by year, month will split files by month, yearmonth
+        will split files by year and month; season will split files by year, day
+        will split files by day.
+
+    Examples
+    ------------
+    If you want to split each file into a dataset into a separate files for each year, do
+    the following:
+
+        >>> data.split("year")
+
+    If you wanted to split by month, do the following:
+
+        >>> data.split("month")
+
+
     """
 
     if by is None:
