@@ -1,5 +1,5 @@
 from nctoolkit.cleanup import cleanup
-from nctoolkit.session import nc_safe
+from nctoolkit.session import nc_safe, append_safe, remove_safe
 from nctoolkit.temp_file import temp_file
 
 
@@ -14,10 +14,11 @@ def to_latlon(self, lon=None, lat=None, res=None, method="bil"):
     lat : list
         2 element list giving minimum and maximum latitude of target grid
     res : float, int or list
-        If float or int given, this will be the horizontal and vertical resolution of the target grid.
-        If 2 element list is given, the first element is the longitudinal resolution and the second is the latitudinal resolution.
+        If float or int given, this will be the horizontal and vertical resolution
+        of the target grid. If 2 element list is given, the first element is the
+        longitudinal resolution and the second is the latitudinal resolution.
     method : str
-        remapping method. Defaults to "bil". Bilinear: "bil"; Nearest neighbour: "nn",....
+        remapping method. Defaults to "bil". Bilinear: "bil"; Nearest neighbour: "nn".
     """
 
     if lon is None:
@@ -96,11 +97,11 @@ def to_latlon(self, lon=None, lat=None, res=None, method="bil"):
     f.write("yinc = " + str(lat_step) + "\n")
     f.close()
 
-    nc_safe.append(grid_file)
+    append_safe(grid_file)
 
     # call regrid
     self.regrid(grid=grid_file, method=method)
 
-    nc_safe.remove(grid_file)
+    remove_safe(grid_file)
 
     cleanup()
