@@ -14,6 +14,19 @@ def to_xarray(self, decode_times=True, cdo_times=False):
     cdo_times: boolean
         Set to True if you do not want CDO to decode the times
 
+    Examples
+    ------------
+    If you want to convert a dataset to an xarray dataset, do the following:
+
+    >>> data.to_xarray()
+
+    This will return an xarray dataset.
+
+    If you do not want time to be decoded, do the following:
+
+    >>> data.to_xarray(decode_times = False)
+
+
     """
     # 3 possibilities:
     #   1: decode_times is False - just open in xarray
@@ -27,8 +40,8 @@ def to_xarray(self, decode_times=True, cdo_times=False):
 
     # if you don't want to decode times, this is straight forward. Just open the data
     if decode_times is False:
-        if type(self.current) is str:
-            data = xr.open_dataset(self.current, decode_times=decode_times)
+        if len(self) == 1:
+            data = xr.open_dataset(self.current[0], decode_times=decode_times)
         else:
             data = xr.open_mfdataset(self.current, decode_times=decode_times)
         return data
@@ -39,8 +52,8 @@ def to_xarray(self, decode_times=True, cdo_times=False):
 
     if cdo_times is False:
         try:
-            if type(self.current) is str:
-                test = xr.open_dataset(self.current, decode_times=decode_times)
+            if len(self) == 1:
+                test = xr.open_dataset(self.current[0], decode_times=decode_times)
             else:
                 test = xr.open_mfdataset(self.current, decode_times=decode_times)
         except Exception as e:
@@ -48,31 +61,30 @@ def to_xarray(self, decode_times=True, cdo_times=False):
 
     # if it does, then just open the data in xarray
 
+    if cdo_times == True and len(self) > 1:
+        raise ValueError("xarray cannot decode times. Set decode_times to False")
+
     if cdo_times is False:
-        if type(self.current) is str:
-            data = xr.open_dataset(self.current, decode_times=decode_times)
+        if len(self) == 1:
+            data = xr.open_dataset(self.current[0], decode_times=decode_times)
         else:
-            data = xr.open_mfdataset(self.current, decode_times=decode_times)
+            data = xr.open_mfdataset(self.current[0], decode_times=decode_times)
         return data
 
     # If it does not, then we use cdo to pull out the times,
     # then push those to the xarray object
 
-    if type(self.current) is str:
+    if len(self) == 1:
 
         times = [
             datetime.strptime(ss.replace("T", " "), "%Y-%m-%d %H:%M:%S")
             for ss in self.times
         ]
 
-        data = xr.open_dataset(self.current, decode_times=False)
+        data = xr.open_dataset(self.current[0], decode_times=False)
         data = data.assign_coords(time=times)
         return data
 
-    else:
-        data = xr.open_mfdataset(self.current, decode_times=decode_times)
-        return data
-
 
 def to_dataframe(self, decode_times=True, cdo_times=False):
     """
